@@ -170,8 +170,10 @@ def make_flags(prefix):
         flags.append("-DWOLFSSL_OLD_NAMES=no")
         flags.append("-DWOLFSSL_EXTENDED_MASTER=no")
         flags.append("-DWOLFSSL_ERROR_STRINGS=no")
+        flags.append("-DWOLFSSL_KEYGEN=yes")
+        flags.append("-DWOLFSSL_AESCTR=yes")
         # Part of hack for missing CMake option
-        flags.append("-DCMAKE_C_FLAGS=\"/DWOLFSSL_KEY_GEN=1 /DWOLFCRYPT_ONLY=1 /DWOLFSSL_AESGCM_STREAM=1 /DWOLFSSL_AES_COUNTER=1\"")
+        flags.append("-DCMAKE_C_FLAGS=\"/DWOLFCRYPT_ONLY=1 /DWOLFSSL_AESGCM_STREAM=1\"")
 
         return " ".join(flags)
     else:
@@ -239,14 +241,10 @@ def cmake_hack():
     with open(options_file, "r") as f:
         contents = f.readlines()
 
-    contents.insert(26, "#undef WOLFSSL_KEY_GEN\n")
-    contents.insert(27, "#define WOLFSSL_KEY_GEN\n")
-    contents.insert(28, "#undef WOLFCRYPT_ONLY\n")
-    contents.insert(29, "#define WOLFCRYPT_ONLY\n")
-    contents.insert(30, "#undef WOLFSSL_AESGCM_STREAM\n")
-    contents.insert(31, "#define WOLFSSL_AESGCM_STREAM\n")
-    contents.insert(32, "#undef WOLFSSL_AES_COUNTER\n")
-    contents.insert(33, "#define WOLFSSL_AES_COUNTER\n")
+    contents.insert(26, "#undef WOLFCRYPT_ONLY\n")
+    contents.insert(27, "#define WOLFCRYPT_ONLY\n")
+    contents.insert(28, "#undef WOLFSSL_AESGCM_STREAM\n")
+    contents.insert(29, "#define WOLFSSL_AESGCM_STREAM\n")
 
     with open(options_file, "w") as f:
         contents = "".join(contents)
